BatchStats

Struct BatchStats 

#[non_exhaustive]
pub struct BatchStats { pub size: usize, pub processing_duration: Duration, pub success: bool, pub item_latencies: Vec<Duration>, pub queue_durations: Vec<Duration>, }
Stats for a completed batch.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
size: usize

The number of items in the batch.

processing_duration: Duration

How long the batch took to process (including resource acquisition if not pre-acquired).

success: bool

Whether the batch processed successfully.

item_latencies: Vec<Duration>

Time from submission to result delivery, for each item in the batch.

queue_durations: Vec<Duration>

Time each item spent in the batch queue before processing started.

Measured from when the worker received the item to when the batch began processing. Includes time waiting for the batch to fill, for concurrency capacity, and for resource acquisition.

Implementations

Source

impl BatchStats

pub fn new( size: usize, processing_duration: Duration, success: bool, item_latencies: Vec<Duration>, queue_durations: Vec<Duration>, ) -> Self

Create a new BatchStats.