#[non_exhaustive]pub struct Limits { /* private fields */ }Expand description
Limits on batch sizes, queueing and concurrency, applied per key.
New items are rejected when the batch queue for their key is full: max_batch_queue_size
batches are queued, and the newest batch already contains max_batch_size items.
max_key_concurrency * max_batch_size is the maximum number of items that can be processed
concurrently for a key, and max_batch_queue_size * max_batch_size is the maximum number of
items that can be queued for a key.
Implementations