pub struct WorkerHandle { /* private fields */ }Expand description
A handle to the worker task.
Used for shutting down the worker and waiting for it to finish.
Implementations
Sourceimpl WorkerHandle
impl WorkerHandle
Sourcepub async fn shut_down(&self)
pub async fn shut_down(&self)
Signal the worker to shut down after processing any in-flight batches.
New items are still accepted while shutting down, and the worker only shuts down once all keys are idle. This means shutdown may never complete if:
- new items keep being added, or
- a batch never meets its policy’s processing condition, e.g. when using the
Sizepolicy, a final partial batch may wait indefinitely for more items.
Stopping the flow of new items is expected to be handled by the caller, e.g. by shutting down the message handlers which add items before shutting down the batcher.
Sourcepub async fn wait_for_shutdown(&self)
pub async fn wait_for_shutdown(&self)
Wait for the worker to finish.